@@ -2,12 +2,14 @@ use crate::checkout::Checkout;
 use crate::context::Context;
 use crate::error::{new_not_found_error, Error};
 use crate::internal_context::InternalContext;
+use crate::money::Money;
 
 use super::{cancel, new, process, queue_for_processing, Payment, PaymentProcessor};
 
 pub async fn create_handler<C: Context + Send>(
     ctx: &mut C,
     checkout_id: String,
+    charge_amount: Money,
     args: <C as PaymentProcessor>::InitiateArgs,
 ) -> Result<
     Payment<
@@ -18,7 +20,7 @@ pub async fn create_handler<C: Context + Send>(
     >,
     Error,
 > {
-    new(ctx, checkout_id, args).await
+    new(ctx, checkout_id, charge_amount, args).await
 }
 
 pub async fn step_handler<C: Context + Send>(
