@@ -2,20 +2,11 @@ use async_trait::async_trait;
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
+use crate::customer::Address;
 use crate::error::Error;
 use crate::item::Item;
 use crate::money::{Currency, Money};
 
-#[derive(Serialize, Deserialize, JsonSchema)]
-pub struct Address {
-    pub line_1: String,
-    pub line_2: Option<String>,
-    pub city: String,
-    pub postal_code: String,
-    pub province: Option<String>,
-    pub country: String,
-}
-
 #[derive(Serialize, Deserialize, JsonSchema)]
 pub enum FulfillmentType {
     Pickup,
